"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var composition_api_1 = require("@vue/composition-api");
function useBeforeUnload(isPageDirty, runOnMount) {
    if (runOnMount === void 0) { runOnMount = true; }
    var isTracking = composition_api_1.ref(false);
    var handleBeforeUnload = function (e) {
        // Show alert message only when isPageDirty is true
        if (isPageDirty.value)
            e.preventDefault();
    };
    var start = function () {
        if (isTracking.value)
            return;
        window.addEventListener('beforeunload', handleBeforeUnload);
        isTracking.value = true;
    };
    var stop = function () {
        if (!isTracking.value)
            return;
        window.removeEventListener('beforeunload', handleBeforeUnload);
        isTracking.value = false;
    };
    composition_api_1.onMounted(function () { return runOnMount && start(); });
    composition_api_1.onUnmounted(stop);
    return { isTracking: isTracking, start: start, stop: stop };
}
exports.useBeforeUnload = useBeforeUnload;
