"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var composition_api_1 = require("@vue/composition-api");
function useMouseLeavePage(runOnMount) {
    if (runOnMount === void 0) { runOnMount = true; }
    var isTracking = composition_api_1.ref(false);
    var hasLeftPage = composition_api_1.ref(false);
    var handleMouseOut = function (e) {
        var from = e.relatedTarget || e.toElement;
        var mouseHasLeftPage = !from || from.nodeName === 'HTML';
        hasLeftPage.value = mouseHasLeftPage;
    };
    var start = function () {
        if (isTracking.value)
            return;
        document.addEventListener('mouseout', handleMouseOut);
        isTracking.value = true;
    };
    var stop = function () {
        if (!isTracking.value)
            return;
        document.removeEventListener('mouseout', handleMouseOut);
        isTracking.value = false;
    };
    composition_api_1.onMounted(function () { return runOnMount && start(); });
    composition_api_1.onUnmounted(stop);
    return { hasLeftPage: hasLeftPage, isTracking: isTracking, start: start, stop: stop };
}
exports.useMouseLeavePage = useMouseLeavePage;
